@@ -316,8 +316,10 @@ func (s *state) WriteRsyncFileOnDisk(path string, data []byte, withdraw bool) er
 	if err != nil {
 		log.Fatal(err)
 	}
-	// GHSA-cqh2-vc2f-q4fh: Prevent parent directory writes outside of Basepath
-	fPath = strings.ReplaceAll(fPath, "../", "")
+	// GHSA-8459-6rc9-8vf8: Prevent parent directory writes outside of Basepath
+	if strings.Contains(fPath, "../") || strings.Contains(fPath, "..\\") {
+		return fmt.Errorf("Path %q contains illegal path element", fPath)
+	}
 
 	f, err := os.Create(filepath.Join(s.Basepath, fPath))
 	if err != nil {
@@ -828,7 +830,7 @@ func (s *state) MainValidation(pSpan opentracing.Span) {
 		manager[i].StrictHash = s.StrictHash
 		manager[i].StrictManifests = s.StrictManifests
 
-		go func(sm *pki.SimpleManager) {
+		go func(sm *pki.SimpleManager, tal *pki.PKIFile) {
 			for err := range sm.Errors {
 				tSpan.SetTag("error", true)
 				tSpan.LogKV("event", "resource issue", "type", "skipping resource", "message", err)
@@ -844,7 +846,7 @@ func (s *state) MainValidation(pSpan opentracing.Span) {
 			}
 
 			//log.Warn("Closed errors")
-		}(sm)
+		}(sm, tal)
 		manager[i].AddInitial([]*pki.PKIFile{tal})
 		s.CountExplore = manager[i].Explore(!s.UseManifest, false)
 
